@@ -1,5 +1,5 @@
 /* main.cc -- main window for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2015 Gerardo Ballabio
+   Copyright (C) 2011-2017 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -106,16 +106,16 @@ bool MainWindow::on_key_press_event(GdkEventKey *event)
   return true;
 }
 
-void MainWindow::on_game_new()
+void MainWindow::on_menu_new()
 {
   if (board.is_game())
     return;
 
   // update actions status
-  actiongroup->get_action("GameNew")->set_sensitive(false);
-  actiongroup->get_action("GameStop")->set_sensitive(true);
-  actiongroup->get_action("GamePrefs")->set_sensitive(false);
-  actiongroup->get_action("GameScores")->set_sensitive(false);
+  action_new->set_enabled(false);
+  action_stop->set_enabled(true);
+  action_prefs->set_enabled(false);
+  action_scores->set_enabled(false);
 
   // select spatial group
   int geometry = preferences.get_geometry();
@@ -196,7 +196,7 @@ void MainWindow::on_game_new()
     (sigc::mem_fun(*this, &MainWindow::on_timeout_down), delay);
 }
 
-void MainWindow::on_game_stop()
+void MainWindow::on_menu_stop()
 {
   if (!board.is_game())
     return;
@@ -211,19 +211,19 @@ void MainWindow::on_game_stop()
   timeout.disconnect();
 
   // update actions status
-  actiongroup->get_action("GameNew")->set_sensitive(true);
-  actiongroup->get_action("GameStop")->set_sensitive(false);
-  actiongroup->get_action("GamePrefs")->set_sensitive(true);
-  actiongroup->get_action("GameScores")->set_sensitive(true);
+  action_new->set_enabled(true);
+  action_stop->set_enabled(false);
+  action_prefs->set_enabled(true);
+  action_scores->set_enabled(true);
 }
 
-void MainWindow::on_game_prefs()
+void MainWindow::on_menu_prefs()
 {
   preferences.reset_page();
   preferences.show();
 }
 
-void MainWindow::on_game_scores()
+void MainWindow::on_menu_scores()
 {
   // I would place this in the constructor
   // if I could made sure that scores is initialized after preferences
@@ -242,18 +242,30 @@ void MainWindow::on_game_scores()
   scores.show();
 }
 
-void MainWindow::on_help_contents()
+void MainWindow::on_menu_help()
 {
   // launch help browser
-  gtk_show_uri(get_screen()->gobj(), "ghelp:galois", GDK_CURRENT_TIME, 0);
+  if (!gtk_show_uri(get_screen()->gobj(),
+		    "ghelp:galois", GDK_CURRENT_TIME, 0))
+    // fall back to html manual (requires network connection)
+    gtk_show_uri(get_screen()->gobj(),
+		 "http://www.nongnu.org/galois/galois.html",
+		 GDK_CURRENT_TIME, 0);
 }
 
-void MainWindow::on_help_about()
+void MainWindow::on_menu_about()
 {
   Gtk::AboutDialog dialog;
-  dialog.set_name("Galois");
-  dialog.set_version("0.4");
+  dialog.set_transient_for(*this);
+
+  // don't show missing icon, I don't like how it looks
+  dialog.set_logo(Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, 1, 1));
+
+  dialog.set_program_name("Galois");
+  dialog.set_version("0.5");
   dialog.set_comments("A falling blocks game with many different geometries");
+  dialog.set_website("http://www.nongnu.org/galois/");
+  dialog.set_copyright("Copyright © 2011-2017 Gerardo Ballabio");
   dialog.set_license
     ("Galois is free software; you can redistribute it and/or modify\n"
      "it under the terms of the GNU General Public License as published by\n"
@@ -267,6 +279,7 @@ void MainWindow::on_help_about()
      "\n"
      "You should have received a copy of the GNU General Public License\n"
      "along with Galois.  If not, see <http://www.gnu.org/licenses/>.");
+
   dialog.run();
 }
 
@@ -436,64 +449,18 @@ void MainWindow::on_game_over()
     scores.show();
 
   // update actions status
-  actiongroup->get_action("GameNew")->set_sensitive(true);
-  actiongroup->get_action("GameStop")->set_sensitive(false);
-  actiongroup->get_action("GamePrefs")->set_sensitive(true);
-  actiongroup->get_action("GameScores")->set_sensitive(true);
+  action_new->set_enabled(true);
+  action_stop->set_enabled(false);
+  action_prefs->set_enabled(true);
+  action_scores->set_enabled(true);
 }
 
 MainWindow::MainWindow()
   : level_label("", 0.0, 0.5), lines_label("", 0.0, 0.5),
-    score_label("", 0.0, 0.5)
+    score_label("", 0.0, 0.5), preferences(*this), scores(*this)
 {
   add(vbox_all);
 
-  // menu bar
-  actiongroup = Gtk::ActionGroup::create();
-  actiongroup->add(Gtk::Action::create("GameMenu", "_Game"));
-  actiongroup->add(Gtk::Action::create("GameNew", Gtk::Stock::NEW),
-		   sigc::mem_fun(*this, &MainWindow::on_game_new));
-  actiongroup->add(Gtk::Action::create("GameStop", Gtk::Stock::STOP),
-		   sigc::mem_fun(*this, &MainWindow::on_game_stop));
-  actiongroup->add(Gtk::Action::create("GamePrefs", Gtk::Stock::PREFERENCES),
-		   sigc::mem_fun(*this, &MainWindow::on_game_prefs));
-  actiongroup->add(Gtk::Action::create("GameScores", "_Scores"),
-		   sigc::mem_fun(*this, &MainWindow::on_game_scores));
-  actiongroup->add(Gtk::Action::create("GameQuit", Gtk::Stock::QUIT),
-		   sigc::mem_fun(*this, &MainWindow::on_game_quit));
-  actiongroup->add(Gtk::Action::create("HelpMenu", "_Help"));
-  actiongroup->add(Gtk::Action::create("HelpContents", Gtk::Stock::HELP,
-				       "_Contents"), Gtk::AccelKey("F1"),
-		   sigc::mem_fun(*this, &MainWindow::on_help_contents));
-  actiongroup->add(Gtk::Action::create("HelpAbout", Gtk::Stock::ABOUT),
-		   sigc::mem_fun(*this, &MainWindow::on_help_about));
-  uimanager = Gtk::UIManager::create();
-  uimanager->insert_action_group(actiongroup);
-  Glib::ustring ui_info =
-    "<ui>"
-    "  <menubar name='MenuBar'>"
-    "    <menu action='GameMenu'>"
-    "      <menuitem action='GameNew'/>"
-    "      <menuitem action='GameStop'/>"
-    "      <menuitem action='GamePrefs'/>"
-    "      <menuitem action='GameScores'/>"
-    "      <menuitem action='GameQuit'/>"
-    "    </menu>"
-    "    <menu action='HelpMenu'>"
-    "      <menuitem action='HelpContents'/>"
-    "      <menuitem action='HelpAbout'/>"
-    "    </menu>"
-    "  </menubar>"
-    "</ui>";
-  uimanager->add_ui_from_string(ui_info);
-  add_accel_group(uimanager->get_accel_group());
-  vbox_all.pack_start(vbox_ui, Gtk::PACK_SHRINK);
-  Gtk::Widget *menubar = uimanager->get_widget("/MenuBar");
-  vbox_ui.pack_start(*menubar, Gtk::PACK_SHRINK);
-
-  // set initial actions status
-  actiongroup->get_action("GameStop")->set_sensitive(false);
-
   // game elements
   vbox_all.pack_start(hbox, Gtk::PACK_EXPAND_WIDGET);
   hbox.pack_start(board_area, Gtk::PACK_EXPAND_WIDGET);
@@ -510,20 +477,81 @@ MainWindow::MainWindow()
     (sigc::mem_fun(*this, &MainWindow::on_response_prefs));
   scores.signal_response().connect
     (sigc::mem_fun(*this, &MainWindow::on_response_scores));
+}
 
-  show_all_children();
+void MainWindow::on_startup(Glib::RefPtr<Gtk::Application> &app)
+{
+  // build application menu
+  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+
+  action_new =
+    add_action("new", sigc::mem_fun(*this, &MainWindow::on_menu_new));
+  app->set_accel_for_action("win.new", "<Primary>n");
+  action_stop =
+    add_action("stop", sigc::mem_fun(*this, &MainWindow::on_menu_stop));
+  Glib::RefPtr<Gio::Menu> section1 = Gio::Menu::create();
+  section1->append("_New Game", "win.new");
+  section1->append("_Stop Game", "win.stop");
+  menu->append_section(section1);
+
+  action_prefs =
+    add_action("prefs", sigc::mem_fun(*this, &MainWindow::on_menu_prefs));
+  action_scores =
+    add_action("scores", sigc::mem_fun(*this, &MainWindow::on_menu_scores));
+  Glib::RefPtr<Gio::Menu> section2 = Gio::Menu::create();
+  section2->append("_Preferences", "win.prefs");
+  section2->append("_Scores", "win.scores");
+  menu->append_section(section2);
+
+  add_action("help", sigc::mem_fun(*this, &MainWindow::on_menu_help));
+  app->set_accel_for_action("win.help", "F1");
+  add_action("about", sigc::mem_fun(*this, &MainWindow::on_menu_about));
+  add_action("quit", sigc::mem_fun(*this, &MainWindow::on_menu_quit));
+  app->set_accel_for_action("win.quit", "<Primary>q");
+  Glib::RefPtr<Gio::Menu> section3 = Gio::Menu::create();
+  section3->append("_Help", "win.help");
+  section3->append("_About", "win.about");
+  section3->append("_Quit", "win.quit");
+  menu->append_section(section3);
+
+  // set initial actions status
+  action_stop->set_enabled(false);
+
+  if (app->prefers_app_menu())
+    app->set_app_menu(menu);
+  // else
+    {
+      // application menu not supported, use menubar
+      Glib::RefPtr<Gio::Menu> menubar = Gio::Menu::create();
+
+      Glib::RefPtr<Gio::Menu> game = Gio::Menu::create();
+      game->append("_New", "win.new");
+      game->append("_Stop", "win.stop");
+      game->append("_Preferences", "win.prefs");
+      game->append("_Scores", "win.scores");
+      game->append("_Quit", "win.quit");
+      menubar->append_submenu("_Game", game);
+
+      Glib::RefPtr<Gio::Menu> help = Gio::Menu::create();
+      help->append("_Contents", "win.help");
+      help->append("_About", "win.about");
+      menubar->append_submenu("_Help", help);
+
+      app->set_menubar(menubar);
+    }
+
+  app->add_window(*this);
+  show_all();
 }
 
 int main(int argc, char *argv[])
 {
-  // initialize gtkmm
-  Gtk::Main kit(argc, argv);
+  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv);
 
-  // create main window
   MainWindow window;
+  app->signal_startup().connect
+    (sigc::bind<Glib::RefPtr<Gtk::Application> &>
+     (sigc::mem_fun(window, &MainWindow::on_startup), app));
 
-  // main loop
-  Gtk::Main::run(window);
-
-  return 0;
+  return app->run(window);
 }
