@@ -1,5 +1,5 @@
 /* main.h -- main window for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2012 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include "preferences.h"
 #include "scores.h"
 
-class MainWindow : public Gtk::Window
+class MainWindow : public Gtk::ApplicationWindow
 {
 private:
   // child widgets
@@ -45,6 +45,10 @@ private:
   PrefsDialog preferences;
   ScoresDialog scores;
 
+  // menu actions
+  Glib::RefPtr<Gio::SimpleAction> action_new, action_stop,
+    action_prefs, action_scores;
+
   // timeout
   sigc::connection timeout;
   int delay; // milliseconds
@@ -57,13 +61,13 @@ private:
 
 protected:
   virtual bool on_key_press_event(GdkEventKey *);
-  virtual void on_game_new();
-  virtual void on_game_stop();
-  virtual void on_game_prefs();
-  virtual void on_game_scores();
-  virtual void on_game_quit() { hide(); }
-  virtual void on_help_contents();
-  virtual void on_help_about();
+  virtual void on_menu_new();
+  virtual void on_menu_stop();
+  virtual void on_menu_prefs();
+  virtual void on_menu_scores();
+  virtual void on_menu_quit() { hide(); }
+  virtual void on_menu_help();
+  virtual void on_menu_about();
   virtual void on_response_prefs(int response_id);
   virtual void on_response_scores(int response_id);
   virtual bool on_timeout_down();
@@ -75,6 +79,8 @@ protected:
 public:
   MainWindow();
   ~MainWindow() { }
+
+  virtual void on_startup(Glib::RefPtr<Gtk::Application> &app);
 };
 
 #endif /* __MAIN_ */
