@@ -1,5 +1,5 @@
 /* preferences.cc -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2014 Gerardo Ballabio
+   Copyright (C) 2011-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -93,8 +93,8 @@ void PrefsDialog::on_geometry_radio_signal_toggled()
       depth_box.set_sensitive(true);
 
       const int min = 4, max = 8;
-      width_adjust.set_lower(min);
-      width_adjust.set_upper(max);
+      width_spin.get_adjustment()->set_lower(min);
+      width_spin.get_adjustment()->set_upper(max);
       width_spin.set_value(width3);
     }
   else
@@ -102,8 +102,8 @@ void PrefsDialog::on_geometry_radio_signal_toggled()
       depth_box.set_sensitive(false);
 
       const int min = 10, max = 20;
-      width_adjust.set_lower(min);
-      width_adjust.set_upper(max);
+      width_spin.get_adjustment()->set_lower(min);
+      width_spin.get_adjustment()->set_upper(max);
       width_spin.set_value(width2);
     }
 }
@@ -113,7 +113,7 @@ void PrefsDialog::on_width_spin_signal_value_changed()
   if (get_geometry_3d())
     {
       width3 = get_width();
-      depth_adjust.set_upper(width3);
+      depth_spin.get_adjustment()->set_upper(width3);
       if (get_depth() > width3)
 	depth_spin.set_value(width3);
     }
@@ -129,7 +129,7 @@ void PrefsDialog::on_mode_combo1_signal_changed()
 void PrefsDialog::on_bricks_spin1_signal_value_changed()
 {
   int max = get_bricks_max();
-  bricks_adjust2.set_upper(max);
+  bricks_spin2.get_adjustment()->set_upper(max);
   if (get_bricks_min() > max)
     bricks_spin2.set_value(max);
 }
@@ -148,10 +148,8 @@ void PrefsDialog::on_three_cell_editing_started(Gtk::CellEditable *cell,
   edit_path = path;
 }
 
-PrefsDialog::PrefsDialog()
-  : Gtk::Dialog("Preferences", true), // modal dialog
-    width_adjust(0, 0, 0), depth_adjust(0, 0, 0), speed_adjust(0, 0, 0),
-    bricks_adjust1(0, 0, 0), bricks_adjust2(0, 0, 0), empty_adjust(0, 0, 0),
+PrefsDialog::PrefsDialog(Gtk::Window &parent)
+  : Gtk::Dialog("Preferences", parent, true), // modal dialog
     width2(10), width3(6), edit_keys(0)
 {
   get_vbox()->pack_start(notebook);
@@ -168,10 +166,9 @@ PrefsDialog::PrefsDialog()
   geometry_box1.pack_start(geometry_heading);
   geometry_heading.set_text("<span weight=\"bold\">Geometry</span>");
   geometry_heading.set_use_markup(true);
-  geometry_heading.set_alignment(Gtk::ALIGN_LEFT);
-  geometry_box1.pack_start(geometry_align);
-  geometry_align.set_padding(0, 0, 12, 0);
-  geometry_align.add(geometry_box2);
+  geometry_heading.set_alignment(Gtk::ALIGN_START);
+  geometry_box1.pack_start(geometry_box2);
+  geometry_box2.set_margin_start(12);
   geometry_box2.set_spacing(6);
   for (unsigned i=0; i<sizeof(geometry_radio)/sizeof(geometry_radio[0]); ++i)
     {
@@ -190,10 +187,7 @@ PrefsDialog::PrefsDialog()
   width_box.pack_start(width_label, Gtk::PACK_SHRINK);
   width_label.set_text("Board width:");
   width_box.pack_start(width_spin, Gtk::PACK_SHRINK);
-  width_spin.set_adjustment(width_adjust);
-  width_adjust.set_lower(10);
-  width_adjust.set_upper(20);
-  width_adjust.set_value(10);
+  width_spin.set_adjustment(Gtk::Adjustment::create(10, 10, 20));
   width_spin.signal_value_changed().connect
     (sigc::mem_fun(*this, &PrefsDialog::on_width_spin_signal_value_changed));
   width_box.pack_start(depth_box, Gtk::PACK_SHRINK);
@@ -201,10 +195,7 @@ PrefsDialog::PrefsDialog()
   depth_box.pack_start(depth_label, Gtk::PACK_SHRINK);
   depth_label.set_text("depth:");
   depth_box.pack_start(depth_spin, Gtk::PACK_SHRINK);
-  depth_spin.set_adjustment(depth_adjust);
-  depth_adjust.set_lower(4);
-  depth_adjust.set_upper(width3);
-  depth_adjust.set_value(width3);
+  depth_spin.set_adjustment(Gtk::Adjustment::create(width3, 4, width3));
   depth_box.set_sensitive(false);
 
   tab_game.pack_start(game_box1, Gtk::PACK_SHRINK);
@@ -212,32 +203,30 @@ PrefsDialog::PrefsDialog()
   game_box1.pack_start(game_heading);
   game_heading.set_text("<span weight=\"bold\">Game</span>");
   game_heading.set_use_markup(true);
-  game_heading.set_alignment(Gtk::ALIGN_LEFT);
-  game_box1.pack_start(game_align);
-  game_align.set_padding(0, 0, 12, 0);
-  game_align.add(game_box2);
+  game_heading.set_alignment(Gtk::ALIGN_START);
+  game_box1.pack_start(game_box2);
+  game_box2.set_margin_start(12);
   game_box2.set_spacing(6);
   game_box2.pack_start(mode_box1);
   mode_box1.pack_start(mode_label1, Gtk::PACK_SHRINK);
   mode_box1.set_spacing(6);
   mode_label1.set_text("On level change: increase");
   mode_box1.pack_start(mode_combo1, Gtk::PACK_SHRINK);
-  mode_combo1.append_text("speed");
-  mode_combo1.append_text("max. block size");
-  mode_combo1.append_text("superblock size");
+  mode_combo1.append("speed");
+  mode_combo1.append("max. block size");
+  mode_combo1.append("superblock size");
   mode_combo1.set_active(0);
   mode_combo1.signal_changed().connect
     (sigc::mem_fun(*this, &PrefsDialog::on_mode_combo1_signal_changed));
-  game_box2.pack_start(mode_align);
-  mode_align.set_padding(0, 0, 12, 0);
-  mode_align.add(mode_box2);
+  game_box2.pack_start(mode_box2);
+  mode_box2.set_margin_start(12);
   mode_box2.set_spacing(6);
   mode_box2.pack_start(mode_label2, Gtk::PACK_SHRINK);
   mode_label2.set_text("and");
   mode_box2.pack_start(mode_combo2, Gtk::PACK_SHRINK);
-  mode_combo2.append_text("decrease");
-  mode_combo2.append_text("keep fixed");
-  mode_combo2.append_text("increase");
+  mode_combo2.append("decrease");
+  mode_combo2.append("keep fixed");
+  mode_combo2.append("increase");
   mode_combo2.set_active(0);
   mode_box2.pack_start(mode_label3, Gtk::PACK_SHRINK);
   mode_label3.set_text("min. block size");
@@ -247,26 +236,17 @@ PrefsDialog::PrefsDialog()
   speed_box.pack_start(speed_label, Gtk::PACK_SHRINK);
   speed_label.set_text("Initial speed level:");
   speed_box.pack_start(speed_spin, Gtk::PACK_SHRINK);
-  speed_spin.set_adjustment(speed_adjust);
-  speed_adjust.set_lower(1);
-  speed_adjust.set_upper(9);
-  speed_adjust.set_value(5);
+  speed_spin.set_adjustment(Gtk::Adjustment::create(5, 1, 9));
   game_box2.pack_start(bricks_box, Gtk::PACK_SHRINK);
   bricks_box.pack_start(bricks_label1, Gtk::PACK_SHRINK);
   bricks_box.set_spacing(6);
   bricks_label1.set_text("Initial block size: maximum");
   bricks_box.pack_start(bricks_spin1, Gtk::PACK_SHRINK);
-  bricks_spin1.set_adjustment(bricks_adjust1);
-  bricks_adjust1.set_lower(4);
-  bricks_adjust1.set_upper(8);
-  bricks_adjust1.set_value(4);
+  bricks_spin1.set_adjustment(Gtk::Adjustment::create(4, 4, 8));
   bricks_box.pack_start(bricks_label2, Gtk::PACK_SHRINK);
   bricks_label2.set_text("minimum");
   bricks_box.pack_start(bricks_spin2, Gtk::PACK_SHRINK);
-  bricks_spin2.set_adjustment(bricks_adjust2);
-  bricks_adjust2.set_lower(2);
-  bricks_adjust2.set_upper(4);
-  bricks_adjust2.set_value(4);
+  bricks_spin2.set_adjustment(Gtk::Adjustment::create(4, 2, 4));
   bricks_spin1.signal_value_changed().connect
     (sigc::mem_fun(*this,
 		   &PrefsDialog::on_bricks_spin1_signal_value_changed));
@@ -275,10 +255,7 @@ PrefsDialog::PrefsDialog()
   empty_box.pack_start(empty_label1, Gtk::PACK_SHRINK);
   empty_label1.set_text("Remove lines with up to");
   empty_box.pack_start(empty_spin, Gtk::PACK_SHRINK);
-  empty_spin.set_adjustment(empty_adjust);
-  empty_adjust.set_lower(0);
-  empty_adjust.set_upper(2);
-  empty_adjust.set_value(0);
+  empty_spin.set_adjustment(Gtk::Adjustment::create(0, 0, 2));
   empty_box.pack_start(empty_label2, Gtk::PACK_SHRINK);
   empty_label2.set_text("empty cells");
 
@@ -287,10 +264,9 @@ PrefsDialog::PrefsDialog()
   view_box1.pack_start(view_heading);
   view_heading.set_text("<span weight=\"bold\">View</span>");
   view_heading.set_use_markup(true);
-  view_heading.set_alignment(Gtk::ALIGN_LEFT);
-  view_box1.pack_start(view_align);
-  view_align.set_padding(0, 0, 12, 0);
-  view_align.add(view_box2);
+  view_heading.set_alignment(Gtk::ALIGN_START);
+  view_box1.pack_start(view_box2);
+  view_box2.set_margin_start(12);
   view_box2.set_spacing(6);
   view_box2.add(next_check);
   next_check.set_label("Preview next block");
@@ -309,10 +285,9 @@ PrefsDialog::PrefsDialog()
   controls_box.pack_start(two_heading);
   two_heading.set_text("<span weight=\"bold\">2D controls</span>");
   two_heading.set_use_markup(true);
-  two_heading.set_alignment(Gtk::ALIGN_LEFT);
-  controls_box.pack_start(two_align);
-  two_align.set_padding(0, 0, 12, 0);
-  two_align.add(two_tree);
+  two_heading.set_alignment(Gtk::ALIGN_START);
+  controls_box.pack_start(two_tree);
+  two_tree.set_margin_start(12);
   two_list = Gtk::ListStore::create(two_columns);
   two_tree.set_model(two_list);
   two_tree.append_column("Action", two_columns.action);
@@ -331,10 +306,9 @@ PrefsDialog::PrefsDialog()
   controls_box.pack_start(three_heading);
   three_heading.set_text("<span weight=\"bold\">3D controls</span>");
   three_heading.set_use_markup(true);
-  three_heading.set_alignment(Gtk::ALIGN_LEFT);
-  controls_box.pack_start(three_align);
-  three_align.set_padding(0, 0, 12, 0);
-  three_align.add(three_tree);
+  three_heading.set_alignment(Gtk::ALIGN_START);
+  controls_box.pack_start(three_tree);
+  three_tree.set_margin_start(12);
   three_list = Gtk::ListStore::create(three_columns);
   three_tree.set_model(three_list);
   three_tree.append_column("Action", three_columns.action);
