@@ -1,5 +1,5 @@
 /* scores.cc -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2012-2014 Gerardo Ballabio
+   Copyright (C) 2012-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,8 +22,6 @@
 #include <libxml++/parsers/textreader.h>
 #include "scores.h"
 
-#include <iostream>
-
 bool ScoresDialog::pass(const std::vector<game>::const_iterator &i) const
 {
   // get current filters
@@ -107,7 +105,7 @@ bool ScoresDialog::on_delete_event(GdkEventAny *event)
   return Gtk::Dialog::on_delete_event(event);
 }
 
-bool ScoresDialog::on_expose_event(GdkEventExpose *event)
+bool ScoresDialog::on_draw(const Cairo::RefPtr<Cairo::Context> &context)
 {
   // request minimal space
   const int min_w = 300, min_h = 100;
@@ -137,7 +135,7 @@ bool ScoresDialog::on_expose_event(GdkEventExpose *event)
     }
 
   // base widget event handler
-  return Gtk::Dialog::on_expose_event(event);
+  return Gtk::Dialog::on_draw(context);
 }
 
 void ScoresDialog::on_cell_edited(const Glib::ustring &path,
@@ -184,42 +182,44 @@ void ScoresDialog::on_check_button_signal_clicked()
 void ScoresDialog::on_imax_spin_signal_value_changed()
 {
   int imax = imax_spin.get_value_as_int();
-  imin_adjust.set_upper(imax);
+  imin_spin.get_adjustment()->set_upper(imax);
   if (imin_spin.get_value_as_int() > imax)
     imin_spin.set_value(imax);
 
   make_list(-1);
 }
 
-ScoresDialog::ScoresDialog()
-  : Gtk::Dialog("Scores", true), // modal dialog
-    geometry_label("", Gtk::ALIGN_LEFT), mode1_label("", Gtk::ALIGN_LEFT),
-    imax_adjust(0, 0, 0), imin_adjust(0, 0, 0), empty_adjust(0, 0, 0),
+ScoresDialog::ScoresDialog(Gtk::Window &parent)
+  : Gtk::Dialog("Scores", parent, true), // modal dialog
+    geometry_label("", Gtk::ALIGN_START), mode1_label("", Gtk::ALIGN_START),
     active_game(-1), active_row(-1)
 {
   get_vbox()->set_spacing(6);
 
   // filters
-  get_vbox()->pack_start(table, Gtk::PACK_SHRINK);
-  table.set_col_spacings(6);
-  table.attach(geometry_label, 0, 1, 0, 1, Gtk::SHRINK | Gtk::FILL);
+  get_vbox()->pack_start(grid, Gtk::PACK_SHRINK);
+  grid.set_margin_start(4);
+  grid.set_column_spacing(6);
+  grid.attach(geometry_label, 0, 0, 1, 1);
   geometry_label.set_label("Brick shape:");
-  table.attach(geometry_combo, 1, 2, 0, 1);
-  geometry_combo.append_text("square");
-  geometry_combo.append_text("hexagonal");
-  geometry_combo.append_text("triangular");
-  geometry_combo.append_text("cubic");
-  geometry_combo.append_text("");
+  grid.attach(geometry_combo, 1, 0, 1, 1);
+  geometry_combo.set_hexpand();
+  geometry_combo.append("square");
+  geometry_combo.append("hexagonal");
+  geometry_combo.append("triangular");
+  geometry_combo.append("cubic");
+  geometry_combo.append("");
   geometry_combo.set_active(0);
   geometry_combo.signal_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
-  table.attach(mode1_label, 0, 1, 1, 2, Gtk::SHRINK | Gtk::FILL);
+  grid.attach(mode1_label, 0, 1, 1, 1);
   mode1_label.set_label("Level change:");
-  table.attach(mode1_combo, 1, 2, 1, 2);
-  mode1_combo.append_text("speed");
-  mode1_combo.append_text("block size");
-  mode1_combo.append_text("superblock size");
-  mode1_combo.append_text("");
+  grid.attach(mode1_combo, 1, 1, 1, 1);
+  mode1_combo.set_hexpand();
+  mode1_combo.append("speed");
+  mode1_combo.append("block size");
+  mode1_combo.append("superblock size");
+  mode1_combo.append("");
   mode1_combo.set_active(0);
   mode1_combo.signal_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
@@ -243,8 +243,8 @@ ScoresDialog::ScoresDialog()
   reflect_box.pack_start(reflect_label, Gtk::PACK_SHRINK);
   reflect_label.set_label("Allow block reflection:");
   reflect_box.pack_start(reflect_combo, Gtk::PACK_SHRINK);
-  reflect_combo.append_text("no");
-  reflect_combo.append_text("yes");
+  reflect_combo.append("no");
+  reflect_combo.append("yes");
   reflect_combo.set_active(0);
   reflect_combo.signal_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
@@ -256,9 +256,9 @@ ScoresDialog::ScoresDialog()
   mode2_box.pack_start(mode2_label1, Gtk::PACK_SHRINK);
   mode2_label1.set_label("On level change:");
   mode2_box.pack_start(mode2_combo, Gtk::PACK_SHRINK);
-  mode2_combo.append_text("decrease");
-  mode2_combo.append_text("keep fixed");
-  mode2_combo.append_text("increase");
+  mode2_combo.append("decrease");
+  mode2_combo.append("keep fixed");
+  mode2_combo.append("increase");
   mode2_combo.set_active(0);
   mode2_combo.signal_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
@@ -272,19 +272,13 @@ ScoresDialog::ScoresDialog()
   size_box.pack_start(imax_label, Gtk::PACK_SHRINK);
   imax_label.set_label("Initial block size: max");
   size_box.pack_start(imax_spin, Gtk::PACK_SHRINK);
-  imax_spin.set_adjustment(imax_adjust);
-  imax_adjust.set_upper(8);
-  imax_adjust.set_lower(4);
-  imax_adjust.set_value(4);
+  imax_spin.set_adjustment(Gtk::Adjustment::create(4, 4, 8));
   imax_spin.signal_value_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_imax_spin_signal_value_changed));
   size_box.pack_start(imin_label, Gtk::PACK_SHRINK);
   imin_label.set_label("min");
   size_box.pack_start(imin_spin, Gtk::PACK_SHRINK);
-  imin_spin.set_adjustment(imin_adjust);
-  imin_adjust.set_upper(4);
-  imin_adjust.set_lower(2);
-  imin_adjust.set_value(4);
+  imin_spin.set_adjustment(Gtk::Adjustment::create(4, 2, 4));
   imin_spin.signal_value_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
   filters_box.pack_start(empty_box);
@@ -295,10 +289,7 @@ ScoresDialog::ScoresDialog()
   empty_box.pack_start(empty_label1, Gtk::PACK_SHRINK);
   empty_label1.set_label("Remove lines with");
   empty_box.pack_start(empty_spin, Gtk::PACK_SHRINK);
-  empty_spin.set_adjustment(empty_adjust);
-  empty_adjust.set_upper(2);
-  empty_adjust.set_lower(0);
-  empty_adjust.set_value(0);
+  empty_spin.set_adjustment(Gtk::Adjustment::create(0, 0, 2));
   empty_spin.signal_value_changed().connect
     (sigc::mem_fun(*this, &ScoresDialog::on_filter_changed));
   empty_box.pack_start(empty_label2, Gtk::PACK_SHRINK);
