@@ -1,5 +1,5 @@
 /* scores.h -- scores dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2012-2014 Gerardo Ballabio
+   Copyright (C) 2012-2015 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ class ScoresDialog : public Gtk::Dialog
 {
 private:
   // filters
-  Gtk::Table table;
+  Gtk::Grid grid;
   ; Gtk::Label geometry_label;
   ; Gtk::ComboBoxText geometry_combo;
   ; Gtk::Label mode1_label;
@@ -104,12 +104,10 @@ private:
   ; ; Gtk::CheckButton size_check;
   ; ; Gtk::Label imax_label, imin_label;
   ; ; Gtk::SpinButton imax_spin, imin_spin;
-  ; ; Gtk::Adjustment imax_adjust, imin_adjust;
   ; Gtk::HBox empty_box;
   ; ; Gtk::CheckButton empty_check;
   ; ; Gtk::Label empty_label1, empty_label2;
   ; ; Gtk::SpinButton empty_spin;
-  ; ; Gtk::Adjustment empty_adjust;
 
   // scores board
   Gtk::ScrolledWindow scroll;
@@ -156,7 +154,7 @@ private:
 protected:
   virtual void on_hide();
   virtual bool on_delete_event(GdkEventAny *event);
-  virtual bool on_expose_event(GdkEventExpose *event);
+  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context> &context);
   virtual void on_cell_edited(const Glib::ustring &path,
 			      const Glib::ustring &text);
   virtual void on_filter_changed() { make_list(-1); }
@@ -164,7 +162,7 @@ protected:
   virtual void on_check_button_signal_clicked();
   virtual void on_imax_spin_signal_value_changed();
 public:
-  ScoresDialog();
+  ScoresDialog(Gtk::Window &parent);
 
   bool is_active() const { return active_row >= 0; }
 
